@@ -3,6 +3,7 @@ table! {
         id -> Integer,
         diffoscope -> Nullable<Text>,
         build_log -> Binary,
+        attestation -> Nullable<Text>,
     }
 }
 
@@ -20,7 +21,7 @@ table! {
         build_id -> Nullable<Integer>,
         built_at -> Nullable<Timestamp>,
         has_diffoscope -> Bool,
-        attestation -> Nullable<Text>,
+        has_attestation -> Bool,
         checksum -> Nullable<Text>,
         retries -> Integer,
         next_retry -> Nullable<Timestamp>,
@@ -45,6 +46,7 @@ table! {
         id -> Integer,
         package_id -> Integer,
         version -> Text,
+        required_backend -> Text,
         priority -> Integer,
         queued_at -> Timestamp,
         worker_id -> Nullable<Integer>,
